<?php
/**
 * airnews functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
 * @subpackage airnews
 * @since 1.0.0
 */
function airnews_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'airnews_content_width', 980 );

}
add_action( 'after_setup_theme', 'airnews_content_width', 0 );

if ( ! function_exists( 'airnews_setup' ) ) :

	function airnews_setup()	{

		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption'
		) ); 
	
		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );
		
		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );
		// Add title tag 
		add_theme_support( 'title-tag' );

		// Add default logo support
		add_theme_support( 'custom-logo');
		
		define( 'DEFAULT_IMAGE', get_template_directory_uri().'/assets/images/blank.jpg');

		add_theme_support( 'post-thumbnails');
		add_image_size('airnews-620x500', 620, 500, true);
		add_image_size('airnews-770x540', 770, 540, true);
		add_image_size('airnews-370x275', 370, 275, true);
		add_image_size('airnews-140x104', 140, 104, true);


		// Menus
		register_nav_menus(array(
			'primary' => esc_html__('Primary Menu', 'airnews'),
		));


		// add excerpt support for pages
		add_post_type_support( 'page', 'excerpt' );
		if ( is_singular() && comments_open() ) {
			wp_enqueue_script( 'comment-reply' );
		}

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Custom Backgrounds
		$defaults = array(	
			'default-image' 	=> '' ,
			'width'         	=> 1920,
			'height'        	=> 540,
			'uploads'       	=> true,
			'default-color' 	=> '#000',
			'wp-head-callback'  => 'airnews_header_style',
		);
		add_theme_support( 'custom-header', $defaults );
				
		// To use additional css
		add_editor_style( 'assets/css/editor-style.css' );
	}

endif;

add_action( 'after_setup_theme',	'airnews_setup' );

// Add Customizer
require get_template_directory() .	'/inc/customizer.php';

// Add widgets
require get_template_directory() .	'/inc/widget.php';

function new_excerpt_more( $more ) {
    return '';
}
add_filter('excerpt_more', 'new_excerpt_more');

/**
 * Enqueue scripts and styles.
 */
function airnews_style() {

		wp_enqueue_style( 'font-Vidaloka', 'https://fonts.googleapis.com/css?family=Merriweather:300,400,700,700i|Vidaloka');
		wp_enqueue_style( 'bootstrap', get_template_directory_uri() .  '/assets/css/bootstrap.css');
        wp_enqueue_style( 'airnews', get_stylesheet_uri() );
		wp_enqueue_style( 'airnews-fontello', get_template_directory_uri() .  '/assets/css/fontello.css');
		wp_enqueue_style( 'airnews-responsive', get_template_directory_uri() .  '/assets/css/responsive.css');
		wp_enqueue_style( 'jquery-owl-carousel',get_template_directory_uri() .  '/assets/css/owl.carousel.css');
		wp_enqueue_style( 'font-awesome', get_template_directory_uri() .  '/assets/css/font-awesome.css');

}
add_action( 'wp_enqueue_scripts', 'airnews_style' );

/**
 * Enqueue JS scripts
 */
if( ! function_exists( 'airnews_enqueue_scripts' ) ) :
	function airnews_enqueue_scripts() {
	    // jquery-->
	    
	    wp_enqueue_script('bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.js', array( 'jquery' ), '', true);
	    wp_enqueue_script('jquery-queryloader2', get_template_directory_uri() . '/assets/js/jquery.queryloader2.js', array(), '', true);
	    wp_enqueue_script('jquery-owl-carousel', get_template_directory_uri() . '/assets/js/owl.carousel.js', array(), '', true);
	    wp_enqueue_script('airnews-plugins', get_template_directory_uri() . '/assets/js/plugins.js', array(), '', true);
	    wp_enqueue_script('airnews-script', get_template_directory_uri() . '/assets/js/script.js', array(), '', true);
	    wp_enqueue_script('airnews-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '', true);
	     wp_enqueue_script('airnews-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), '', true);



	}
	add_action( 'wp_enqueue_scripts', 'airnews_enqueue_scripts' );
endif;


function airnews_custom_excerpt_length( $length ) {
	return 30;
}
add_filter( 'excerpt_length', 'airnews_custom_excerpt_length', 999 );


add_action( 'widgets_init', 'airnews_themeposts_list_widget' );
function airnews_themeposts_list_widget() {
	register_widget( 'airnews_themeposts_list' );
}
class airnews_themeposts_list extends WP_Widget {

	public function __construct(){
		$widget_ops 	= array( 'classname' => 'posts-list'  );
		$control_ops 	= array( 'width' => 250, 'height' => 350, 'id_base' => 'posts-list-widget' );
		parent::__construct( 'posts-list-widget', esc_html__( 'airnews Latest Post' ,'airnews' ), $widget_ops, $control_ops );
	}

	public function widget( $args, $instance ) {
		extract( $args );

		$title 			= apply_filters('widget_title', $instance['title'] );
		$no_of_posts 	= $instance['no_of_posts'];
		$thumb 			= ! empty( $instance['thumb'] ) ? $instance['thumb'] : false;

		print_r( $before_widget);
		if ( ! empty( $title ) ):
			print_r( $before_title);
			print_r( $title); 
		endif;
		print_r( $after_title); ?>
		<?php
			global $post;
			$original_post = $post;
			$args = array(
				'posts_per_page'		 => $no_of_posts,
				'no_found_rows'          => true,
				'ignore_sticky_posts'	 => true
			);
			$get_posts_query = new WP_Query( $args ); ?>

			<div class="post-area">
				<?php
					if ( $get_posts_query->have_posts() ):
						while ( $get_posts_query->have_posts() ) : $get_posts_query->the_post()?>
							<article class="post-item">
									<?php if ( function_exists("has_post_thumbnail") && has_post_thumbnail() && $thumb ) : ?>
										<div class="post-thumbnail">
											<div class="caption">
												<?php the_post_thumbnail( 'airnews-140x104'); ?>
											</div>
										</div>
									<?php else: ?>
										<div class="post-thumbnail">
											<div class="caption">
												<img class="size-airnews-140x104" src="<?php echo esc_attr( DEFAULT_IMAGE ); ?>" alt="<?php esc_attr__('default','airnews')?>">
											</div>
										</div>
									<?php endif; ?>
									<div class="entry-header">
										<div class="entry-meta">
											<ul class="default-list-disk">
												<li>
												<span class="posted-on">
													<a rel="bookmark">
														<time class="entry-date" ><?php echo esc_html( get_the_date(), 'airnews' ); ?></time>
													</a>
												</span>
												</li>
											</ul>
										</div>
										<h3 class="entry-title">
											<a href="<?php the_permalink(); ?>"><?php the_title();?></a>
										</h3>
									</div>
							</article>
						<?php
						endwhile;
					endif; ?>
			</div>	

			<?php wp_reset_query(); ?>
			<?php print_r( $after_widget );
	}

	public function update( $new_instance, $old_instance ) {
		$instance 					= $old_instance;
		$instance['title'] 			= strip_tags( $new_instance['title'] );
		$instance['no_of_posts'] 	= strip_tags( $new_instance['no_of_posts'] );
		$instance['posts_order'] 	= strip_tags( $new_instance['posts_order'] );
		$instance['thumb'] 			= strip_tags( $new_instance['thumb'] );
		return $instance;
	}

	public function form( $instance ) {
		$defaults = array( 'title' =>esc_html__('Recent Posts' , 'airnews') , 'no_of_posts' => '5' , 'posts_order' => 'latest', 'thumb' => 'true' );
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<p>
			<label for="<?php print esc_attr( $this->get_field_id( 'title' ), 'airnews' ); ?>"><?php echo esc_html__( 'Title:' , 'airnews'); ?></label>
			<input id="<?php print esc_attr( $this->get_field_id( 'title' ), 'airnews' ); ?>" name="<?php print esc_attr( $this->get_field_name( 'title' ), 'airnews' ); ?>" value="<?php if( !empty($instance['title']) ) echo esc_html( $instance['title']); ?>" class="widefat" type="text" />
		</p>
		<p>
			<label for="<?php print esc_attr( $this->get_field_id( 'no_of_posts' ), 'airnews' ); ?>"><?php esc_html_e( 'Number of posts to show:' , 'airnews') ?></label>
			<input id="<?php print esc_attr( $this->get_field_id( 'no_of_posts' ), 'airnews' ); ?>" name="<?php print esc_attr( $this->get_field_name( 'no_of_posts' ), 'airnews' ); ?>" value="<?php if( !empty($instance['no_of_posts']) ) echo esc_html( $instance['no_of_posts']); ?>" type="text" size="3" />
		</p>
		
		<p>
			<label for="<?php print esc_attr( $this->get_field_id( 'thumb' ), 'airnews' ); ?>"><?php esc_html_e( 'Display Thumbnails:' , 'airnews') ?></label>
			<input id="<?php print esc_attr( $this->get_field_id( 'thumb' ), 'airnews' ); ?>" name="<?php print esc_attr( $this->get_field_name( 'thumb' ), 'airnews' ); ?>" value="false" <?php if( !empty( $instance['thumb'] ) ) echo esc_attr('checked=""', 'airnews' ); ?> type="checkbox" />
		</p>
	<?php
	}
}

function airnews_header_style() {
$header_text_color = get_header_textcolor(); ?>
	<style type="text/css">
			.site-title, .site-description{
				color: #<?php echo esc_attr($header_text_color); ?>;
				
			}

			<?php
				//Check if user has defined any header image.
				if ( get_header_image() ) :
			?>
			.border-top-content
			  {
				background-image:url('<?php header_image(); ?>');
				background-size:cover;
			  }

			<?php endif; ?>	
	</style>
<?php }